Crate panes

Crate panes 

Re-exports

pub use resolver::ResolvedLayout;

Modules

compiler
diff
resolver
runtime

Macros

layout
Declarative macro for building layouts from a concise DSL.

Structs

CenteredMaster
Columns
Constraints
Spatial constraints for a panel within a layout.
ContainerCtx
Closure context for building container children.
Dashboard
Deck
Dwindle
Gap
Newtype for gap values. Validated when consumed by row()/col().
Grid
HolyGrail
Layout
An immutable, validated layout ready for resolution.
LayoutBuilder
Ergonomic builder for constructing layouts.
LayoutTree
Arena-based mutable layout tree.
MasterStack
Monocle
NodeId
Opaque unique identifier for a node in the layout tree.
PanelId
Opaque unique identifier for a panel.
PanelIdGenerator
Generates sequential, unique PanelId values.
Rect
Axis-aligned rectangle defined by origin (x, y) and size (w, h).
Scrollable
Sidebar
Spiral
Split
Stacked
Tabbed
ViewportState
Viewport state for interactive layouts.

Enums

Node
A node in the layout tree.
PaneError
Errors arising from layout operations on panels and nodes.
Position
Relative position for inserting or moving nodes within a container.

Functions

fixed
Create constraints with a fixed size.
gap
Create a gap value for use in row() and col() containers.
grow
Create constraints with a grow factor.