Re-exports
pub use resolver::ResolvedLayout;
Modules
Macros
- layout
- Declarative macro for building layouts from a concise DSL.
Structs
- Centered
Master - Columns
- Constraints
- Spatial constraints for a panel within a layout.
- Container
Ctx - Closure context for building container children.
- Dashboard
- Deck
- Dwindle
- Gap
- Newtype for gap values. Validated when consumed by
row()/col(). - Grid
- Holy
Grail - Layout
- An immutable, validated layout ready for resolution.
- Layout
Builder - Ergonomic builder for constructing layouts.
- Layout
Tree - Arena-based mutable layout tree.
- Master
Stack - Monocle
- NodeId
- Opaque unique identifier for a node in the layout tree.
- PanelId
- Opaque unique identifier for a panel.
- Panel
IdGenerator - Generates sequential, unique
PanelIdvalues. - Rect
- Axis-aligned rectangle defined by origin (x, y) and size (w, h).
- Scrollable
- Sidebar
- Spiral
- Split
- Stacked
- Tabbed
- Viewport
State - Viewport state for interactive layouts.
Enums
- Node
- A node in the layout tree.
- Pane
Error - Errors arising from layout operations on panels and nodes.
- Position
- Relative position for inserting or moving nodes within a container.